@@ -1,6 +1,7 @@
 from gridfs import GridFS
 from pymongo import MongoClient
 
+from . import get_valid_kwargs
 from .base import BaseCache, BaseStorage
 from .mongo import MongoDict
 
@@ -9,19 +10,21 @@ class GridFSCache(BaseCache):
     """GridFS cache backend.
     Use this backend to store documents greater than 16MB.
 
-    Usage:
-        requests_cache.install_cache(backend='gridfs')
+    Example:
 
-    Or:
-        from pymongo import MongoClient
-        requests_cache.install_cache(backend='gridfs', connection=MongoClient('another-host.local'))
+        >>> requests_cache.install_cache(backend='gridfs')
+
+        Or:
+        >>> from pymongo import MongoClient
+        >>> requests_cache.install_cache(backend='gridfs', connection=MongoClient('alternate-host'))
+
+    Args:
+        db_name: Database name
+        connection: :py:class:`pymongo.MongoClient` object to reuse instead of creating a new one
+        kwargs: Additional keyword arguments for :py:class:`pymongo.MongoClient`
     """
 
-    def __init__(self, db_name, **kwargs):
-        """
-        :param db_name: database name
-        :param connection: (optional) ``pymongo.Connection``
-        """
+    def __init__(self, db_name: str, **kwargs):
         super().__init__(**kwargs)
         self.responses = GridFSPickleDict(db_name, **kwargs)
         kwargs['connection'] = self.responses.connection
@@ -29,21 +32,19 @@ class GridFSCache(BaseCache):
 
 
 class GridFSPickleDict(BaseStorage):
-    """A dictionary-like interface for a GridFS collection"""
+    """A dictionary-like interface for a GridFS database
+
+    Args:
+        db_name: Database name
+        collection_name: Ignored; GridFS internally uses collections 'fs.files' and 'fs.chunks'
+        connection: :py:class:`pymongo.MongoClient` object to reuse instead of creating a new one
+        kwargs: Additional keyword arguments for :py:class:`pymongo.MongoClient`
+    """
 
     def __init__(self, db_name, collection_name=None, connection=None, **kwargs):
-        """
-        :param db_name: database name (be careful with production databases)
-        :param connection: ``pymongo.Connection`` instance. If it's ``None``
-                           (default) new connection with default options will
-                           be created
-        """
         super().__init__(**kwargs)
-        if connection is not None:
-            self.connection = connection
-        else:
-            self.connection = MongoClient()
-
+        connection_kwargs = get_valid_kwargs(MongoClient, kwargs)
+        self.connection = connection or MongoClient(**connection_kwargs)
         self.db = self.connection[db_name]
         self.fs = GridFS(self.db)
 
@@ -51,14 +52,16 @@ class GridFSPickleDict(BaseStorage):
         result = self.fs.find_one({'_id': key})
         if result is None:
             raise KeyError
-        return self.deserialize(result.read())
+        return self.serializer.loads(result.read())
 
     def __setitem__(self, key, item):
         try:
             self.__delitem__(key)
         except KeyError:
             pass
-        self.fs.put(self.serialize(item), **{'_id': key})
+        value = self.serializer.dumps(item)
+        encoding = None if isinstance(value, bytes) else 'utf-8'
+        self.fs.put(value, encoding=encoding, **{'_id': key})
 
     def __delitem__(self, key):
         res = self.fs.find_one({'_id': key})
@@ -76,6 +79,3 @@ class GridFSPickleDict(BaseStorage):
     def clear(self):
         self.db['fs.files'].drop()
         self.db['fs.chunks'].drop()
-
-    def __str__(self):
-        return str(dict(self.items()))
