@@ -2,7 +2,7 @@
 
 Short description:
 * The ``mock_session`` fixture uses pre-configured mock requests, and should be used for unit tests.
-* The ``tempfile_session`` fixture makes real HTTP requests, and should be used for integration test.
+* The ``tempfile_session`` fixture makes real HTTP requests, and should be used for integration tests.
 
 Note: The protocol ``http(s)+mock://`` helps :py:class:`requests_mock.Adapter` play nicely with
 :py:class:`requests.PreparedRequest`. More info here:
@@ -10,8 +10,10 @@ https://requests-mock.readthedocs.io/en/latest/adapter.html
 """
 import os
 import pytest
+from datetime import datetime, timezone
 from functools import wraps
 from logging import basicConfig, getLogger
+from os.path import abspath, dirname, join
 from tempfile import NamedTemporaryFile
 
 import requests
@@ -22,16 +24,56 @@ from timeout_decorator import timeout
 import requests_cache
 from requests_cache.session import ALL_METHODS, CachedSession
 
+CACHE_NAME = 'pytest_cache'
+
+# Allow running longer stress tests with an environment variable
+STRESS_TEST_MULTIPLIER = int(os.getenv('STRESS_TEST_MULTIPLIER', '1'))
+N_THREADS = 2 * STRESS_TEST_MULTIPLIER
+N_ITERATIONS = 4 * STRESS_TEST_MULTIPLIER
+
+HTTPBIN_METHODS = ['GET', 'POST', 'PUT', 'PATCH', 'DELETE']
+HTTPBIN_FORMATS = [
+    'brotli',
+    'deflate',
+    'deny',
+    'encoding/utf8',
+    'gzip',
+    'html',
+    'image/jpeg',
+    'image/png',
+    'image/svg',
+    'image/webp',
+    'json',
+    'robots.txt',
+    'xml',
+]
+
+HTTPDATE_STR = 'Fri, 16 APR 2021 21:13:00 GMT'
+HTTPDATE_DATETIME = datetime(2021, 4, 16, 21, 13, tzinfo=timezone.utc)
+
 MOCKED_URL = 'http+mock://requests-cache.com/text'
 MOCKED_URL_HTTPS = 'https+mock://requests-cache.com/text'
 MOCKED_URL_JSON = 'http+mock://requests-cache.com/json'
 MOCKED_URL_REDIRECT = 'http+mock://requests-cache.com/redirect'
 MOCKED_URL_REDIRECT_TARGET = 'http+mock://requests-cache.com/redirect_target'
+MOCKED_URL_404 = 'http+mock://requests-cache.com/nonexistent'
 MOCK_PROTOCOLS = ['mock://', 'http+mock://', 'https+mock://']
 
-# Configure logging to show debug output when tests fail (or with pytest -s)
+PROJECT_DIR = abspath(dirname(dirname(__file__)))
+SAMPLE_DATA_DIR = join(PROJECT_DIR, 'tests', 'sample_data')
+SAMPLE_CACHE_FILES = [join(SAMPLE_DATA_DIR, path) for path in os.listdir(SAMPLE_DATA_DIR)]
+
+AWS_OPTIONS = {
+    'endpoint_url': 'http://localhost:8000',
+    'region_name': 'us-east-1',
+    'aws_access_key_id': 'placeholder',
+    'aws_secret_access_key': 'placeholder',
+}
+
+
+# Configure logging to show log output when tests fail (or with pytest -s)
 basicConfig(level='INFO')
-getLogger('requests_cache').setLevel('DEBUG')
+# getLogger('requests_cache').setLevel('DEBUG')
 logger = getLogger(__name__)
 
 
@@ -79,13 +121,8 @@ def mock_session() -> CachedSession:
             db_path=temp.name,
             backend='sqlite',
             allowable_methods=ALL_METHODS,
-            suppress_warnings=True,
         )
-        adapter = get_mock_adapter()
-        for protocol in MOCK_PROTOCOLS:
-            session.mount(protocol, adapter)
-        session.mock_adapter = adapter
-        yield session
+        yield mount_mock_adapter(session)
 
 
 @pytest.fixture(scope='function')
@@ -96,11 +133,17 @@ def tempfile_session() -> CachedSession:
             cache_name=temp.name,
             backend='sqlite',
             allowable_methods=ALL_METHODS,
-            suppress_warnings=True,
         )
         yield session
 
 
+@pytest.fixture(scope='function')
+def tempfile_path() -> CachedSession:
+    """Get a tempfile path that will be deleted after the test finishes"""
+    with NamedTemporaryFile(suffix='.db') as temp:
+        yield temp.name
+
+
 @pytest.fixture(scope='function')
 def installed_session() -> CachedSession:
     """Get a CachedSession using a temporary SQLite db, with global patching.
@@ -111,12 +154,19 @@ def installed_session() -> CachedSession:
             cache_name=temp.name,
             backend='sqlite',
             allowable_methods=ALL_METHODS,
-            suppress_warnings=True,
         )
         yield requests.Session()
     requests_cache.uninstall_cache()
 
 
+def mount_mock_adapter(session: CachedSession) -> CachedSession:
+    adapter = get_mock_adapter()
+    for protocol in MOCK_PROTOCOLS:
+        session.mount(protocol, adapter)
+    session.mock_adapter = adapter
+    return session
+
+
 def get_mock_adapter() -> Adapter:
     """Get a requests-mock Adapter with some URLs mocked by default"""
     adapter = Adapter()
@@ -155,6 +205,11 @@ def get_mock_adapter() -> Adapter:
         text='mock redirected response',
         status_code=200,
     )
+    adapter.register_uri(
+        ANY_METHOD,
+        MOCKED_URL_404,
+        status_code=404,
+    )
     return adapter
 
 
@@ -170,9 +225,15 @@ def fail_if_no_connection(func) -> bool:
     @wraps(func)
     def wrapper(*args, **kwargs):
         try:
-            timeout(1.0)(func)(*args, **kwargs)
+            timeout(1.0, use_signals=False)(func)(*args, **kwargs)
         except Exception as e:
             logger.error(e)
             pytest.fail('Could not connect to backend')
 
     return wrapper
+
+
+def assert_delta_approx_equal(dt1: datetime, dt2: datetime, target_delta, threshold_seconds=2):
+    """Assert that the given datetimes are approximately ``target_delta`` seconds apart"""
+    diff_in_seconds = (dt2 - dt1).total_seconds()
+    assert abs(diff_in_seconds - target_delta) <= threshold_seconds
